Module profile_api

Module profile_api 

Enums

GetProfileDataError
struct for typed errors of method get_profile_data
GetProfileStatsError
struct for typed errors of method get_profile_stats

Functions

get_profile_data
Get the player profile from the available GDPR data. DE now has the profile endpoint behind authentication, and all requests will timeout.
get_profile_stats
Get the player profile from the available GDPR data. DE now has the profile endpoint behind authentication, and all requests will timeout.