Enums
- GetAcolyte
Data Error - struct for typed errors of method
get_acolyte_data - GetArcanes
Data Error - struct for typed errors of method
get_arcanes_data - GetConclave
Data Error - struct for typed errors of method
get_conclave_data - GetEvents
Data Error - struct for typed errors of method
get_events_data - GetFactions
Data Error - struct for typed errors of method
get_factions_data - GetFissures
Data Error - struct for typed errors of method
get_fissures_data - GetLanguage
Data Error - struct for typed errors of method
get_language_data - GetLocales
Error - struct for typed errors of method
get_locales - GetMission
Data Error - struct for typed errors of method
get_mission_data - GetNode
Data Error - struct for typed errors of method
get_node_data - GetOperations
Data Error - struct for typed errors of method
get_operations_data - GetSortie
Data Error - struct for typed errors of method
get_sortie_data - GetSyndicate
Data Error - struct for typed errors of method
get_syndicate_data - GetTutorial
Data Error - struct for typed errors of method
get_tutorial_data - GetUpgrade
Types Data Error - struct for typed errors of method
get_upgrade_types_data
Functions
- get_
acolyte_ data - Persistent Enemy translation information for aiding translation of identifiers.
- get_
arcanes_ data - Available Arcane Enhancements
- get_
conclave_ data - Data about conclave challenges
- get_
events_ data - Data about events
- get_
factions_ data - Strings for translating faction identifiers.
- get_
fissures_ data - Fissure translation identifiers
- get_
language_ data - Get language strings to assist translation. (Prefer the /languages/search/:query route)
- get_
locales - Locales supported by the API
- get_
mission_ data - Mission Type information to aid translating identifiers
- get_
node_ data - Sol Node translation information for aiding the translation of identifiers.
- get_
operations_ data - Operation Types information to aid translating identifiers for global upgrades
- get_
sortie_ data - Sortie translation information for assisting translation of identifiers.
- get_
syndicate_ data - Information to assist translating syndicate identifiers.
- get_
tutorial_ data - Tutorials data from DE
- get_
upgrade_ types_ data - Upgrade types for what can be changed by global modifiers, such as double credit weekends.