pub async fn get_operations_data(
configuration: &Configuration,
) -> Result<OperationTypes, Error<GetOperationsDataError>>Expand description
Operation Types information to aid translating identifiers for global upgrades
pub async fn get_operations_data(
configuration: &Configuration,
) -> Result<OperationTypes, Error<GetOperationsDataError>>Operation Types information to aid translating identifiers for global upgrades