Module worldstate_api

Module worldstate_api 

Enums

GetAcolytesByPlatformError
struct for typed errors of method get_acolytes_by_platform
GetAlertsByPlatformError
struct for typed errors of method get_alerts_by_platform
GetArbitrationByPlatformError
struct for typed errors of method get_arbitration_by_platform
GetArchonHuntByPlatformError
struct for typed errors of method get_archon_hunt_by_platform
GetBaroByPlatformError
struct for typed errors of method get_baro_by_platform
GetCambionByPlatformError
struct for typed errors of method get_cambion_by_platform
GetCetusByPlatformError
struct for typed errors of method get_cetus_by_platform
GetConclaveChallengesByPlatformError
struct for typed errors of method get_conclave_challenges_by_platform
GetConstructionByPlatformError
struct for typed errors of method get_construction_by_platform
GetDarkSectorsByPlatformError
struct for typed errors of method get_dark_sectors_by_platform
GetDealsByPlatformError
struct for typed errors of method get_deals_by_platform
GetDeepArchimedeaByPlatformError
struct for typed errors of method get_deep_archimedea_by_platform
GetEarthByPlatformError
struct for typed errors of method get_earth_by_platform
GetEventsByPlatformError
struct for typed errors of method get_events_by_platform
GetFissuresByPlatformError
struct for typed errors of method get_fissures_by_platform
GetGlobalEffectsByPlatformError
struct for typed errors of method get_global_effects_by_platform
GetInvasionsByPlatformError
struct for typed errors of method get_invasions_by_platform
GetKuvaByPlatformError
struct for typed errors of method get_kuva_by_platform
GetNewsByPlatformError
struct for typed errors of method get_news_by_platform
GetNightwaveByPlatformError
struct for typed errors of method get_nightwave_by_platform
GetOutpostsByPlatformError
struct for typed errors of method get_outposts_by_platform
GetRivensByPlatformError
struct for typed errors of method get_rivens_by_platform
GetSalesByPlatformError
struct for typed errors of method get_sales_by_platform
GetSimarisByPlatformError
struct for typed errors of method get_simaris_by_platform
GetSortieByPlatformError
struct for typed errors of method get_sortie_by_platform
GetSteelPathByPlatformError
struct for typed errors of method get_steel_path_by_platform
GetSyndicatesByPlatformError
struct for typed errors of method get_syndicates_by_platform
GetTimestampByPlatformError
struct for typed errors of method get_timestamp_by_platform
GetVallisByPlatformError
struct for typed errors of method get_vallis_by_platform
GetVarziaByPlatformError
struct for typed errors of method get_varzia_by_platform
GetVoidTradersByPlatformError
struct for typed errors of method get_void_traders_by_platform
GetWorldstateByPlatformError
struct for typed errors of method get_worldstate_by_platform
SearchRivensByPlatformError
struct for typed errors of method search_rivens_by_platform

Functions

get_acolytes_by_platform
Data about current acolytes attacking the Sol System
get_alerts_by_platform
Description and rewards for Alerts
get_arbitration_by_platform
Description of the currently active arbitration
get_archon_hunt_by_platform
Data about the missions for the current archon hunt
get_baro_by_platform
Information on the current Void Trader offerings, or when he will arrive.
get_cambion_by_platform
Data on the Vome/Fass cycle for the Cambion Drift on Deimos
get_cetus_by_platform
Data on the day/night cycle for Cetus on Earth
get_conclave_challenges_by_platform
Data on each day and week’s conclave challenges
get_construction_by_platform
Construction percentages for showing how far constructed the enemy fleets are.
get_dark_sectors_by_platform
Dark Sector (Rail Wars) data and history. Digital Extremes has emptied several of these.
get_deals_by_platform
Darvo’s Daily Deal details
get_deep_archimedea_by_platform
Data on current Deep Archimedea missions, deviations, risk variables, and personal modifiers may not be up to date and, in some cases, may be omitted from the world state.
get_earth_by_platform
The current Earth day/night cycle progress.
get_events_by_platform
Events, such as Fomorian Attacks are included here
get_fissures_by_platform
Information about current Void Fissure missions
get_global_effects_by_platform
Any current modifiers applied to all users, such as double drops.
get_invasions_by_platform
Data on invasion missions, such as estimated completion time, rewards, etc.
get_kuva_by_platform
Current Kuva Mission listing (provided by semlar).
get_news_by_platform
Translated News items from the worldstate
get_nightwave_by_platform
The Current cycle and challenges of Nightwave, a battle-pass-esque rotation and challenge system
get_outposts_by_platform
Status data for current Sentient Outpost, if any. Parsed source is combined data from DE\’s worldstate and semlar\’s data
get_rivens_by_platform
Data about averages, deviations, medians, miniums, and maxes for all rivens for the provided platform
get_sales_by_platform
Popular Deals, discounts, featured deals.
get_simaris_by_platform
Status data for Simaris’ Sanctuary
get_sortie_by_platform
Data about the missions for the current sortie
get_steel_path_by_platform
Data about the missions for the current sortie
get_syndicates_by_platform
Cycling through different nodes each day, these are a general listing of the nodes that each syndicate will use for the day.
get_timestamp_by_platform
The time that the worldstate was last generated
get_vallis_by_platform
The current cycle of the Orb Vallis warm/cold cycle
get_varzia_by_platform
Information on the current Varzia offerings, or when she will arrive.
get_void_traders_by_platform
Information on the current Void Traders offerings, or when they will arrive.
get_worldstate_by_platform
The full translated Warframe Worldstate
search_rivens_by_platform
Data about averages, deviations, medians, miniums, and maxes for rivens whose name match the query for the provided platform