pub struct Event {Show 34 fields
pub id: Option<String>,
pub activation: Option<String>,
pub expiry: Option<String>,
pub maximum_score: Option<f64>,
pub current_score: Option<f64>,
pub small_interval: Option<f64>,
pub large_interval: Option<f64>,
pub faction: Option<Faction>,
pub description: Option<String>,
pub tooltip: Option<String>,
pub node: Option<String>,
pub concurrent_nodes: Option<Vec<String>>,
pub victim_node: Option<String>,
pub score_loc_tag: Option<String>,
pub rewards: Option<Vec<Reward>>,
pub health: Option<f64>,
pub affiliated_with: Option<Syndicate>,
pub jobs: Option<Vec<SyndicateJob>>,
pub interim_steps: Option<Vec<EventAllOfInterimSteps>>,
pub progress_steps: Option<Vec<EventAllOfProgressSteps>>,
pub progress_total: Option<f64>,
pub show_total_at_end_of_mission: Option<bool>,
pub is_personal: Option<bool>,
pub is_community: Option<bool>,
pub region_drops: Option<Vec<String>>,
pub archwing_drops: Option<Vec<String>>,
pub as_string: Option<String>,
pub metadata: Option<Value>,
pub completion_bonuses: Option<Vec<f64>>,
pub score_var: Option<String>,
pub alt_expiry: Option<String>,
pub alt_activation: Option<String>,
pub next_alt: Option<Box<EventAllOfNextAlt>>,
pub tag: Option<String>,
}Fields
id: Option<String>unique identifier for this object/event/thing
activation: Option<String>ISO-8601 formatted timestamp for when the event began
expiry: Option<String>A timestamp in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ) representing a specific point in time. This format is commonly used in APIs to ensure consistent date and time representation. The timestamp is in UTC (Coordinated Universal Time) and does not include any timezone offset. It is used to represent events, deadlines, or any time-related information in a standardized way. Example: "2023-10-01T12:00:00Z" represents October 1, 2023, at 12:00 PM UTC.
maximum_score: Option<f64>Maximum score to complete the event
current_score: Option<f64>The current score for the event
small_interval: Option<f64>Interval for the first goal
large_interval: Option<f64>Interval for the second intermediate score
faction: Option<Faction>description: Option<String>The description or "subtitle" for the event.
tooltip: Option<String>Tooltip for the event
node: Option<String>Node that the event is taking place on
concurrent_nodes: Option<Vec<String>>Nodes that the event is happening concurrently on
victim_node: Option<String>Node that is being attacked & defended in the event.
score_loc_tag: Option<String>Localized tag for the event score
rewards: Option<Vec<Reward>>health: Option<f64>Amount of health remaining for the target
affiliated_with: Option<Syndicate>jobs: Option<Vec<SyndicateJob>>interim_steps: Option<Vec<EventAllOfInterimSteps>>Interim steps, marking progress towards the final goal.
progress_steps: Option<Vec<EventAllOfProgressSteps>>progress_total: Option<f64>Total of progressSteps values.
show_total_at_end_of_mission: Option<bool>Whether to show the total score at the end of the mission
is_personal: Option<bool>Whether the event is personal
is_community: Option<bool>Whether the event is communal
region_drops: Option<Vec<String>>Drops in the area around the event node
archwing_drops: Option<Vec<String>>Archwing Drops in effect while this event is active
as_string: Option<String>Attempt to summarize event in a short string. (Do not use).
metadata: Option<Value>Miscellaneous metadata in a string provided by Digital Extremes
completion_bonuses: Option<Vec<f64>>Completion bonus amounts per-stage
score_var: Option<String>Internal string used for unknown purpose
alt_expiry: Option<String>Alternate Expiry. Use unknown.
alt_activation: Option<String>Alternate Activation. Use unknown.
next_alt: Option<Box<EventAllOfNextAlt>>tag: Option<String>A unique identifier or category label for the event, used to group or filter related events.