pub enum MissionType {
Show 37 variants
AncientRetribution,
Arena,
Assassination,
Assault,
Capture,
Conclave,
DarkSectorDefection,
DarkSectorDefense,
DarkSectorDisruption,
DarkSectorExcavation,
DarkSectorSabotage,
DarkSectorSurvival,
Defense,
Disruption,
Excavation,
ExterminationLeftParenthesisArchwingRightParenthesis,
Extermination,
FreeRoam,
Hijack,
Hive,
HiveSabotage,
Interception,
InterceptionLeftParenthesisArchwingRightParenthesis,
MobileDefense,
MobileDefenseLeftParenthesisArchwingRightParenthesis,
OrokinSabotage,
Orphix,
PursuitLeftParenthesisArchwingRightParenthesis,
Relay,
Rescue,
RushLeftParenthesisArchwingRightParenthesis,
Sabotage,
SabotageLeftParenthesisArchwingRightParenthesis,
Skirmish,
Spy,
Survival,
Volatile,
}Expand description
MissionType : A Warframe mision type, the kind of game mode that the mission/node houses. A Warframe mision type, the kind of game mode that the mission/node houses.
Variants
AncientRetribution
Arena
Assassination
Assault
Capture
Conclave
DarkSectorDefection
DarkSectorDefense
DarkSectorDisruption
DarkSectorExcavation
DarkSectorSabotage
DarkSectorSurvival
Defense
Disruption
Excavation
ExterminationLeftParenthesisArchwingRightParenthesis
Extermination
FreeRoam
Hijack
Hive
HiveSabotage
Interception
InterceptionLeftParenthesisArchwingRightParenthesis
MobileDefense
MobileDefenseLeftParenthesisArchwingRightParenthesis
OrokinSabotage
Orphix
PursuitLeftParenthesisArchwingRightParenthesis
Relay
Rescue
RushLeftParenthesisArchwingRightParenthesis
Sabotage
SabotageLeftParenthesisArchwingRightParenthesis
Skirmish
Spy
Survival
Volatile