pub struct PersistentEnemiesInner {
pub location_tag: Option<String>,
pub agent_type: Option<String>,
pub rank: Option<f64>,
pub health_percent: Option<f64>,
pub flee_damage: Option<f64>,
pub region: Option<String>,
pub last_discovered_time: Option<String>,
pub last_discovered_at: Option<String>,
pub is_discovered: Option<bool>,
pub is_using_ticketing: Option<bool>,
pub pid: Option<String>,
}Fields
location_tag: Option<String>Location tag for Acolyte
agent_type: Option<String>Which acolyte it is
rank: Option<f64>Enemy level
health_percent: Option<f64>Enemy’s remaining health
flee_damage: Option<f64>The percent damage that the enemy takes when it’s defeated
region: Option<String>The region in which the enemy is located
last_discovered_time: Option<String>The time at which the enemy was last discovered
last_discovered_at: Option<String>Node at which the enemy was last discovered
is_discovered: Option<bool>Whether the enemy is currently discovered
is_using_ticketing: Option<bool>Whether the enemy is using ‘ticketing’. Unknown usage.
pid: Option<String>faux-id incorporating the actual description and Whether the enemy is discovered.
Implementations
Sourceimpl PersistentEnemiesInner
impl PersistentEnemiesInner
pub fn new() -> PersistentEnemiesInner