Enums
- GetProfile
Data Error - struct for typed errors of method
get_profile_data - GetProfile
Stats Error - struct for typed errors of method
get_profile_stats
Functions
- get_
profile_ data - Get the player profile from the available GDPR data. DE now has the profile endpoint behind authentication, and all requests will timeout.
- get_
profile_ stats - Get the player profile from the available GDPR data. DE now has the profile endpoint behind authentication, and all requests will timeout.