Module static_processing_data_api

Module static_processing_data_api 

Enums

GetAcolyteDataError
struct for typed errors of method get_acolyte_data
GetArcanesDataError
struct for typed errors of method get_arcanes_data
GetConclaveDataError
struct for typed errors of method get_conclave_data
GetEventsDataError
struct for typed errors of method get_events_data
GetFactionsDataError
struct for typed errors of method get_factions_data
GetFissuresDataError
struct for typed errors of method get_fissures_data
GetLanguageDataError
struct for typed errors of method get_language_data
GetLocalesError
struct for typed errors of method get_locales
GetMissionDataError
struct for typed errors of method get_mission_data
GetNodeDataError
struct for typed errors of method get_node_data
GetOperationsDataError
struct for typed errors of method get_operations_data
GetSortieDataError
struct for typed errors of method get_sortie_data
GetSyndicateDataError
struct for typed errors of method get_syndicate_data
GetTutorialDataError
struct for typed errors of method get_tutorial_data
GetUpgradeTypesDataError
struct for typed errors of method get_upgrade_types_data

Functions

get_acolyte_data
Persistent Enemy translation information for aiding translation of identifiers.
get_arcanes_data
Available Arcane Enhancements
get_conclave_data
Data about conclave challenges
get_events_data
Data about events
get_factions_data
Strings for translating faction identifiers.
get_fissures_data
Fissure translation identifiers
get_language_data
Get language strings to assist translation. (Prefer the /languages/search/:query route)
get_locales
Locales supported by the API
get_mission_data
Mission Type information to aid translating identifiers
get_node_data
Sol Node translation information for aiding the translation of identifiers.
get_operations_data
Operation Types information to aid translating identifiers for global upgrades
get_sortie_data
Sortie translation information for assisting translation of identifiers.
get_syndicate_data
Information to assist translating syndicate identifiers.
get_tutorial_data
Tutorials data from DE
get_upgrade_types_data
Upgrade types for what can be changed by global modifiers, such as double credit weekends.