pub struct Invasion {Show 20 fields
pub id: Option<String>,
pub activation: Option<String>,
pub expiry: Option<String>,
pub attacker: Option<Box<InvasionAllOfAttacker>>,
pub attacker_reward: Option<Box<InvasionAllOfAttackerReward>>,
pub attacking_faction: String,
pub completed: bool,
pub completion: f64,
pub count: f32,
pub defender: Option<Box<InvasionAllOfDefender>>,
pub defender_reward: Option<Box<InvasionAllOfDefenderReward>>,
pub defending_faction: String,
pub desc: String,
pub eta: Option<String>,
pub node: String,
pub node_key: Option<String>,
pub required_runs: f64,
pub reward_types: Option<Vec<RewardType>>,
pub start_string: Option<String>,
pub vs_infestation: bool,
}Fields
id: Option<String>unique identifier for this object/event/thing
activation: Option<String>ISO-8601 formatted timestamp for when the event began
expiry: Option<String>A timestamp in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ) representing a specific point in time. This format is commonly used in APIs to ensure consistent date and time representation. The timestamp is in UTC (Coordinated Universal Time) and does not include any timezone offset. It is used to represent events, deadlines, or any time-related information in a standardized way. Example: "2023-10-01T12:00:00Z" represents October 1, 2023, at 12:00 PM UTC.
attacker: Option<Box<InvasionAllOfAttacker>>attacker_reward: Option<Box<InvasionAllOfAttackerReward>>attacking_faction: Stringcompleted: boolWhether this invasion is "over"
completion: f64percentage complete as a float value
count: f32How many fights have happened.
defender: Option<Box<InvasionAllOfDefender>>defender_reward: Option<Box<InvasionAllOfDefenderReward>>defending_faction: Stringdesc: Stringdescription of invasion
eta: Option<String>time string showing approximate time to the end of the invasion
node: Stringlocalized Node name
node_key: Option<String>i18n key for matching node (always english translation)
required_runs: f64How many runs of this mission are needed to qualify for the reward
reward_types: Option<Vec<RewardType>>start_string: Option<String>vs_infestation: bool